==> apache-log4cxx-1.3.1.zip: apache-log4cxx-1.3.1/src/site/markdown/community.md <==
Community {#community}
===
<!--
 Note: License header cannot be first, as doxygen does not generate
 cleanly if it before the '==='
-->
<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->

# Getting help {#support}

If you are using an older version, search the [change log], [JIRA] and [mailing list archives]
to determine whether your problem has been fixed some time ago.

If you already digged through the code and found a problem in the Log4cxx implementation
or the Log4cxx build scripts, feel free to directly raise an issue in [Github Issues].
*Please don't just open bugs only because things don't work for you*,
some issues simply aren't bugs in the code base of the project or it's build tools,
but may have a lot of different other reasons.

If things really only don't work and you don't have any clue why,
please use the [official support channels],
i.e., [usage mailing list](mailto:log4cxx-user@logging.apache.org),
[developer mailing lists](mailto:log4cxx-dev@logging.apache.org)
or [GitHub Discussions] instead.

# Reporting a security issue {#security}

Refer to the [official security page] for how to get support on security issues.

# Official releases {#artifacts}

See [artifact locations] for where you can get offical release artifacts and how to verify them.

[change log]:@ref changelog
[JIRA]: https://issues.apache.org/jira/browse/LOGCXX
[mailing list archives]: http://mail-archives.apache.org/mod_mbox/logging-log4cxx-user
[Github Issues]: https://github.com/apache/logging-log4cxx/issues
[GitHub Discussions]: https://github.com/apache/logging-log4cxx/discussions
[official support channels]: https://logging.apache.org/support.html
[official security page]: https://logging.apache.org/security.html
[artifact locations]: https://logging.apache.org/download.html

==> apache-log4cxx-1.6.0.zip: apache-log4cxx-1.6.0/src/site/markdown/community.md <==
Community {#community}
===
<!--
 Note: License header cannot be first, as doxygen does not generate
 cleanly if it before the '==='
-->
<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->

# Getting help {#support}

If you are using an older version, search the [change log], [JIRA] and [mailing list archives]
to determine whether your problem has been fixed some time ago.

If you already digged through the code and found a problem in the Log4cxx implementation
or the Log4cxx build scripts, feel free to directly raise an issue in [Github Issues].
*Please don't just open bugs only because things don't work for you*,
some issues simply aren't bugs in the code base of the project or it's build tools,
but may have a lot of different other reasons.

If things really only don't work and you don't have any clue why,
please use the [official support channels] instead,
i.e., [GitHub Discussions]
or [developer mailing lists].

# Reporting a security issue {#security}

Refer to the [official security page] for how to get support on security issues.

# Official releases {#artifacts}

See [artifact locations] for where you can get offical release artifacts and how to verify them.

[change log]:@ref changelog
[JIRA]: https://issues.apache.org/jira/browse/LOGCXX
[mailing list archives]: https://lists.apache.org/list.html?dev@logging.apache.org
[Github Issues]: https://github.com/apache/logging-log4cxx/issues
[GitHub Discussions]: https://github.com/apache/logging-log4cxx/discussions
[developer mailing lists]: mailto:dev@logging.apache.org
[official support channels]: https://logging.apache.org/support.html
[official security page]: https://logging.apache.org/security.html
[artifact locations]: https://logging.apache.org/download.html
